==> DQScriptsDemo_0_2_1.zip: DQScriptsDemo_0_2_1/rgss-lib/dq/menu/Window_Actor_Menu_Item_Use.rb <==
#==============================================================================
#  Window_Actor_Menu_Item_Use
#------------------------------------------------------------------------------
# ɁHEBhE
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

class Window_Actor_Menu_Item_Use < Window_Actor_Menu_Base
  #----------------------------------------------------------------------------
  # 
  #----------------------------------------------------------------------------
  def initialize(parent)
    super(parent,'ɁH')

    # ʒu̐ݒ
    item_win = get_window(Window_Item)
    self.top  = item_win.top
    self.left = item_win.right
  end

  #--------------------------------------------------------------------------
  # XV
  #--------------------------------------------------------------------------
  def update
    if @message_end
      get_window(Window_Item_Menu).dispose
      get_window(Window_Item).refresh
      return
    end
    super
  end

  #--------------------------------------------------------------------------
  # AN^[I
  #--------------------------------------------------------------------------
  def select_actor
    target_actor = self.actor
    owner_actor = get_window(Window_Actor_Menu_Item).actor
    owner_actor = get_window(Window_Actor_Menu_Item).backpack if owner_actor.nil?
    item = get_window(Window_Item).item
    if not Item_Facade.item_can_use?(item,owner_actor,target_actor)
      e = Script_Event.new
      e.message("#{owner_actor.name}́@#{target_actor.name}Ɂ@#{item.name}B")
      e.message("AȂɂȂB")
      e.brank
      $scene.interpreter.setup e.event_commands, 0
      @message_end = true
      return
    end
    used = Item_Facade.use_item(item,owner_actor,[target_actor])
    # ACegꍇ
    if used
      # Sł̏ꍇ
      if $game_party.all_dead?
        # Q[I[o[ʂɐ؂ւ
        $scene = Scene_Gameover.new
        return
      end
      # RCxg ID L̏ꍇ
      if item.common_event_id > 0
        # RCxgĂяo\
        $game_temp.common_event_id = item.common_event_id
        # }bvʂɐ؂ւ
        $scene = Scene_Map.new
        return
      end
      msgs = []
      if owner_actor.class.method_defined?('name')
        msgs.push "#{owner_actor.name}́@#{item.name}B"
      else
        msgs.push "#{target_actor.name}́@#{item.name}B"
      end

# TOOD ACeɃbZ[Wݒ肷Kv

      e = Script_Event.new
      for msg in msgs
        e.message(msg)
      end
      e.brank
      $scene.interpreter.setup e.event_commands, 0
      @message_end = true
      return
    end
  end
end

end

==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/menu/Window_Actor_Menu_Item_Use.rb <==
#==============================================================================
#  Window_Actor_Menu_Item_Use
#------------------------------------------------------------------------------
# ɁHEBhE
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

class Window_Actor_Menu_Item_Use < Window_Actor_Menu_Base
  include Menu_Log_Item_Module

  #----------------------------------------------------------------------------
  # 
  #----------------------------------------------------------------------------
  def initialize(parent)
    super(parent,'ɁH')

    # ʒu̐ݒ
    item_win = get_window(Window_Item)
    self.top  = item_win.top
    self.left = item_win.right
  end

  #--------------------------------------------------------------------------
  # XV
  #--------------------------------------------------------------------------
  def update
    if @message_end
      get_window(Window_Item_Menu).dispose
      get_window(Window_Item).refresh
      return
    end
    super
  end

  #--------------------------------------------------------------------------
  # AN^[I
  #--------------------------------------------------------------------------
  def select_actor
    target_actor = self.actor
    owner_actor = get_window(Window_Actor_Menu_Item).actor
    owner_actor = get_window(Window_Actor_Menu_Item).backpack if owner_actor.nil?
    item = get_window(Window_Item).item
    if not Item_Facade.item_can_use?(item,owner_actor,target_actor)
      menu_log_use_item_miss(item,owner_actor,target_actor)
      @message_end = true
      return
    end
    used = Item_Facade.use_item(item,owner_actor,[target_actor])
    # ACegꍇ
    if used
      menu_log_use_item(item,owner_actor,[target_actor])
      @message_end = true
      return
    end
  end
end

end
